searchData={"items":[{"type":"module","title":"tls_certificate_check","doc":"Main API","ref":"tls_certificate_check.html"},{"type":"type","title":"tls_certificate_check.option/0","doc":"","ref":"tls_certificate_check.html#t:option/0"},{"type":"function","title":"tls_certificate_check.options/1","doc":"Returns the list of  ssl:connect  options necessary to validate the server certificate against a list of trusted authorities, as well as to verify whether the server hostname matches one in the server certificate. Target  can be either a hostname or an HTTP URL, as  iodata()","ref":"tls_certificate_check.html#options/1"},{"type":"type","title":"tls_certificate_check.override_source/0","doc":"","ref":"tls_certificate_check.html#t:override_source/0"},{"type":"function","title":"tls_certificate_check.override_trusted_authorities/1","doc":"Overrides the trusted authorities with a custom source.","ref":"tls_certificate_check.html#override_trusted_authorities/1"},{"type":"function","title":"tls_certificate_check.trusted_authorities/0","doc":"Returns the list of trusted authorities.","ref":"tls_certificate_check.html#trusted_authorities/0"},{"type":"extras","title":"tls_certificate_check","doc":"# tls\\_certificate\\_check\n\n[![Hex downloads](https://img.shields.io/hexpm/dt/tls_certificate_check.svg)](https://hex.pm/packages/tls_certificate_check)\n[![License](https://img.shields.io/hexpm/l/tls_certificate_check.svg)](https://github.com/g-andrade/tls_certificate_check/blob/master/LICENSE)\n[![Erlang Versions](https://img.shields.io/badge/Erlang%2FOTP-24%20to%2027-blue)](https://www.erlang.org)\n[![CI status](https://github.com/g-andrade/tls_certificate_check/actions/workflows/ci.yml/badge.svg)](https://github.com/g-andrade/tls_certificate_check/actions/workflows/ci.yml)\n[![Latest version](https://img.shields.io/hexpm/v/tls_certificate_check.svg?style=flat)](https://hex.pm/packages/tls_certificate_check)\n[![API reference](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/tls_certificate_check/)\n[![Last commit](https://img.shields.io/github/last-commit/g-andrade/tls_certificate_check.svg)](https://github.com/g-andrade/tls_certificate_check/commits/master)\n\n`tls_certificate_check` is a library for Erlang/OTP and Elixir that\ntries to make it easier to establish [more secure HTTPS\nconnections](https://wiki.mozilla.org/index.php?title=CA/IncludedCertificates&redirect=no)\nin ordinary setups.\n\nOther kinds of TLS/SSL connections may also benefit from it.\n\nIt blends a CA trust store with\n[ssl\\_verify\\_fun](https://github.com/deadtrickster/ssl_verify_fun.erl)\nto verify remote hostnames,\nas well as the boilerplate to validate [misordered\ncertificate chains](https://github.com/elixir-mint/mint/issues/95).\n\nThe\n[OTP-trusted CAs](https://www.erlang.org/doc/man/public_key.html#cacerts_get-0)\n(typically provided by the OS) are used on OTP 25+ unless unavailable or opted-out[^1],\nin which case `tls_certificate_check` falls back to a hardcoded [Mozilla's CA certificate\nstore](https://curl.se/docs/caextract.html), as extracted by `curl`.\nWhen on OTP 24 or older, the lib will initialize using only the latter.\n\nThe trusted authorities' certificates are loaded when the application\nstarts and made available to the API through\n[`persistent_term`](https://erlang.org/doc/man/persistent_term.html)[^2]. After that, they can\nbe explicitly overridden through the API.","ref":"readme.html"},{"type":"extras","title":"How to use - tls_certificate_check","doc":"#### Erlang\n\n##### 1\\. Import as a dependency\n\nrebar.config\n\n``` erlang\n{deps, [\n    % [...]\n    {tls_certificate_check, \"~> 1.28\"}\n]}.\n```\n\nyour\\_application.app.src\n\n``` erlang\n{applications, [\n    kernel,\n    stdlib,\n    % [...]\n    tls_certificate_check\n]}\n```\n\n##### 2\\. Make your connections safer\n\n``` erlang\nHost = \"example.com\",\nOptions = tls_certificate_check:options(Host),\nssl:connect(Host, 443, Options, 5000)\n```\n\n#### Elixir\n\n##### 1\\. Import as a dependency\n\nmix.exs\n\n``` elixir\n  defp deps do\n    [\n      # [...]\n      {:tls_certificate_check, \"~> 1.28\"}\n    ]\n  end\n```\n\n##### 2\\. Make your connections safer\n\n``` elixir\nhost = \"example.com\"\noptions = :tls_certificate_check.options(host)\nhost |> String.to_charlist() |> :ssl.connect(443, options, 5000)\n```","ref":"readme.html#how-to-use"},{"type":"extras","title":"Advanced Use - tls_certificate_check","doc":"#### Overriding Trusted CAs\n\n##### Erlang\n\n```erlang\nPath = certifi:cacertfile(),\ntls_certificate_check:override_trusted_authorities({file, Path})\n```\n\n##### Elixir\n\n```elixir\npath = CAStore.file_path()\n:tls_certificate_check.override_trusted_authorities({:file, path})\n```","ref":"readme.html#advanced-use"},{"type":"extras","title":"API Reference - tls_certificate_check","doc":"The API reference can be found on\n[HexDocs](https://hexdocs.pm/tls_certificate_check/).","ref":"readme.html#api-reference"},{"type":"extras","title":"Tested setup - tls_certificate_check","doc":"- Erlang/OTP 24 or newer\n  - rebar3","ref":"readme.html#tested-setup"},{"type":"extras","title":"License - tls_certificate_check","doc":"MIT License\n\nCopyright (c) 2020-2024 Guilherme Andrade\n\nPermission is hereby granted, free of charge, to any person obtaining a\ncopy of this software and associated documentation files (the\n\"Software\"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be included\nin all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS\nOR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.\nIN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY\nCLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,\nTORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE\nSOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.\n\n---\n\n[^1]: the use of OTP-trusted CAs can be controlled through the `use_otp_trusted_CAs` boolean\noption within application env config.\n\n[^2]: the persistent term key is derived from the CA store's own contents and existing keys\nare not erased until the app terminates gracefully - this minimizes the risk of an impactful\nglobal garbage collection.","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)\nand this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).\n\n## [1.28.0] - 2025-05-23","ref":"changelog.html"},{"type":"extras","title":"Changed - Changelog","doc":"- module with bundled CAs to latest as of 2025/05/20, 03:12 UTC\n(source: https://curl.se/ca/cacert.pem)\n- oldest OTP version supported from 22 to 24\n- CI from Ubuntu 20.04 to 22.04","ref":"changelog.html#changed"},{"type":"extras","title":"Removed - Changelog","doc":"- [certificate authority] AAA Certificate Services\n- [certificate authority] baltimore cybertrust root\n- [certificate authority] entrust.net certification authority (2048)\n- [certificate authority] globalsign root ca\n- [certificate authority] go daddy class 2 certification authority\n- [certificate authority] starfield class 2 certification authority\n- [certificate authority] xramp global certification authority\n\n## [1.27.0] - 2025-02-25","ref":"changelog.html#removed"},{"type":"extras","title":"Added - Changelog","doc":"- [certificate authority] d-trust br root ca 2 2023\n- [certificate authority] d-trust ev root ca 2 2023\n- OTP 27.2 to CI","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- module with bundled CAs to latest as of 2025/02/25, 04:12 UTC\n(source: https://curl.se/ca/cacert.pem)","ref":"changelog.html#changed-1"},{"type":"extras","title":"Removed - Changelog","doc":"- [certificate authority] swisssign silver ca - g2\n\n## [1.26.0] - 2025-01-09","ref":"changelog.html#removed-1"},{"type":"extras","title":"Changed - Changelog","doc":"- module with bundled CAs to latest as of 2024/12/31, 04:12 UTC\n(source: https://curl.se/ca/cacert.pem)","ref":"changelog.html#changed-2"},{"type":"extras","title":"Removed - Changelog","doc":"- [certificate authority] securesign rootca11\n- [certificate authority] security communication rootca3\n- [certificate authority] entrust root certification authority - g4\n\n## [1.25.0] - 2024-12-15","ref":"changelog.html#removed-2"},{"type":"extras","title":"Added - Changelog","doc":"- OTP 27.1 to CI\n- [certificate authority] globaltrust 2020","ref":"changelog.html#added-1"},{"type":"extras","title":"Changed - Changelog","doc":"- module with bundled CAs to latest as of 2024/11/26, 13:58 UTC\n(source: https://curl.se/ca/cacert.pem)","ref":"changelog.html#changed-3"},{"type":"extras","title":"Fixed - Changelog","doc":"- problematic lack of unix permissions for 'other' among some of the source\n  files, affecting environments that preserve said permissions and import,\n  process or in other ways depend on `tls_certificate_check` under a different\n  user account & group from those that own the file (thanks\n  https://github.com/kivra-pauoli, closes issue #52)\n\n## [1.24.0] - 2024-09-24","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- [certificate authority] securesign root ca12\n- [certificate authority] securesign root ca14\n- [certificate authority] securesign root ca15\n- [certificate authority] twca cyber root ca","ref":"changelog.html#added-2"},{"type":"extras","title":"Changed - Changelog","doc":"- module with bundled CAs to latest as of 2024/09/24, 03:12 UTC\n(source: https://curl.se/ca/cacert.pem)\n\n## [1.23.0] - 2024-07-09","ref":"changelog.html#changed-4"},{"type":"extras","title":"Added - Changelog","doc":"- [certificate authority] FIRMAPROFESIONAL CA ROOT-A WEB\n- OTP 27.0 to CI","ref":"changelog.html#added-3"},{"type":"extras","title":"Changed - Changelog","doc":"- module with bundled CAs to latest as of 2024/07/02, 03:12 UTC\n(source: https://curl.se/ca/cacert.pem)","ref":"changelog.html#changed-5"},{"type":"extras","title":"Removed - Changelog","doc":"- [certificate authority] globaltrust 2020\n\n## [1.22.1] - 2024-03-16","ref":"changelog.html#removed-3"},{"type":"extras","title":"Changed - Changelog","doc":"- README\n\n## [1.22.0] - 2024-03-16","ref":"changelog.html#changed-6"},{"type":"extras","title":"Added - Changelog","doc":"- [certificate authority] Telekom Security TLS ECC Root 2020\n- [certificate authority] Telekom Security TLS RSA Root 2023\n- OTP 26.2 to CI","ref":"changelog.html#added-4"},{"type":"extras","title":"Changed - Changelog","doc":"- module with bundled CAs to latest as of 2024/03/11, 15:25 UTC\n(source: https://curl.se/ca/cacert.pem)","ref":"changelog.html#changed-7"},{"type":"extras","title":"Fixed - Changelog","doc":"- Elixir example of how to use `tls_certificate_check` with `ssl:connect/4`\n(thanks https://github.com/macifell)\n\n## [1.21.0] - 2023-12-12","ref":"changelog.html#fixed-1"},{"type":"extras","title":"Added - Changelog","doc":"- [certificate authority] CommScope Public Trust ECC Root-01\n- [certificate authority] CommScope Public Trust ECC Root-02\n- [certificate authority] CommScope Public Trust RSA Root-01\n- [certificate authority] CommScope Public Trust RSA Root-02\n- [certificate authority] TrustAsia Global Root CA G3\n- [certificate authority] TrustAsia Global Root CA G4\n- OTP 26.1 to CI","ref":"changelog.html#added-5"},{"type":"extras","title":"Changed - Changelog","doc":"- module with bundled CAs to latest as of 2023/12/12, 04:12 UTC\n(source: https://curl.se/ca/cacert.pem)","ref":"changelog.html#changed-8"},{"type":"extras","title":"Removed - Changelog","doc":"- [certificate authority] Autoridad de Certificacion Firmaprofesional CIF A62634068\n- [certificate authority] security communication rootca1\n\n## [1.20.0] - 2023-08-22","ref":"changelog.html#removed-4"},{"type":"extras","title":"Added - Changelog","doc":"- [certificate authority] Atos TrustedRoot Root CA ECC TLS 2021\n- [certificate authority] Atos TrustedRoot Root CA RSA TLS 2021\n- [certificate authority] SSL.com TLS ECC Root CA 2022\n- [certificate authority] SSL.com TLS RSA Root CA 2022\n- [certificate authority] sectigo public server authentication root e46\n- [certificate authority] sectigo public server authentication root r46","ref":"changelog.html#added-6"},{"type":"extras","title":"Changed - Changelog","doc":"- module with bundled CAs to latest as of 2023/08/22, 03:12 UTC\n(source: https://curl.se/ca/cacert.pem)","ref":"changelog.html#changed-9"},{"type":"extras","title":"Removed - Changelog","doc":"- [certificate authority] e-tugra global root ca ecc v3\n- [certificate authority] e-tugra global root ca rsa v3\n\n## [1.19.0] - 2023-05-30","ref":"changelog.html#removed-5"},{"type":"extras","title":"Added - Changelog","doc":"- OTP 26.0 to CI\n- [certificate authority] BJCA Global Root CA2\n- [certificate authority] BJCA Global Root CA1","ref":"changelog.html#added-7"},{"type":"extras","title":"Changed - Changelog","doc":"- CI to use latest rebar3 version that's compatible with each covered OTP release\n- module with bundled CAs to latest as of 2023/05/30, 03:12 UTC\n(source: https://curl.se/ca/cacert.pem)","ref":"changelog.html#changed-10"},{"type":"extras","title":"Removed - Changelog","doc":"- [certificate authority] hongkong post root ca 1\n- [certificate authority] E-Tugra Certification Authority\n\n## [1.18.1] - 2023-05-01","ref":"changelog.html#removed-6"},{"type":"extras","title":"Changed - Changelog","doc":"- import of `ssl_verify_fun` to match latest allowed 1.x version","ref":"changelog.html#changed-11"},{"type":"extras","title":"Fixed - Changelog","doc":"- failing tests and checks on macOS ventura (maybe ARM specific)\n\n## [1.18.0] - 2023-03-20","ref":"changelog.html#fixed-2"},{"type":"extras","title":"Added - Changelog","doc":"- explicit SNI, to account for TCP sockets upgraded to `ssl`\nwith `ssl:connect/3`\n- OTP 25.3 to CI","ref":"changelog.html#added-8"},{"type":"extras","title":"Fixed - Changelog","doc":"- CI deprecation warnings\n\n## [1.17.4] - 2023-02-19","ref":"changelog.html#fixed-3"},{"type":"extras","title":"Fixed - Changelog","doc":"- error starting application when OS-trusted CAs fail to load on OTP 25\n[present since 1.17.0]\n\n## [1.17.3] - 2023-01-17","ref":"changelog.html#fixed-4"},{"type":"extras","title":"Fixed - Changelog","doc":"- (rare?) crash after reading OS-trusted CAs\n\n## [1.17.2] - 2023-01-12","ref":"changelog.html#fixed-5"},{"type":"extras","title":"Fixed - Changelog","doc":"- listing of private modules and functions in generated reference\n\n## [1.17.1] - 2023-01-12","ref":"changelog.html#fixed-6"},{"type":"extras","title":"Fixed - Changelog","doc":"- unreleased version in change log\n\n## [1.17.0] - 2023-01-11","ref":"changelog.html#fixed-7"},{"type":"extras","title":"Added - Changelog","doc":"- ability to override trusted CAs\n- Windows to CI\n- OTP 25.2 to CI","ref":"changelog.html#added-9"},{"type":"extras","title":"Changed - Changelog","doc":"- default CAs to the ones trusted by OTP (typically provided by the OS), when available, on OTP 25+\n- shared state owner to not erase its `persistent_term`s when crashing\n- module with bundled CAs to latest as of 2023/01/10, 04:12 UTC\n(source: https://curl.se/ca/cacert.pem)","ref":"changelog.html#changed-12"},{"type":"extras","title":"Removed - Changelog","doc":"- [certificate authority] network solutions certificate authority\n- [certificate authority] TrustCor ECA-1\n- [certificate authority] TrustCor RootCert CA-1\n- [certificate authority] Staat der Nederlanden EV Root CA\n- [certificate authority] TrustCor RootCert CA-2\n\n## [1.16.0] - 2022-10-11","ref":"changelog.html#removed-7"},{"type":"extras","title":"Added - Changelog","doc":"- OTP 25.1 to CI\n- [certificate authority] security communication ecc rootca1\n- [certificate authority] security communication rootca3","ref":"changelog.html#added-10"},{"type":"extras","title":"Changed - Changelog","doc":"- module with bundled CAs to latest as of 2022/10/11, 03:12 UTC\n(source: https://curl.se/ca/cacert.pem)\n\n## [1.15.0] - 2022-07-20","ref":"changelog.html#changed-13"},{"type":"extras","title":"Added - Changelog","doc":"- OTP 25 to CI\n- [certificate authority] certainly root e1\n- [certificate authority] digicert tls ecc p384 root g5\n- [certificate authority] e-tugra global root ca ecc v3\n- [certificate authority] certainly root r1\n- [certificate authority] digicert tls rsa4096 root g5\n- [certificate authority] e-tugra global root ca rsa v3","ref":"changelog.html#added-11"},{"type":"extras","title":"Changed - Changelog","doc":"- module with bundled CAs to latest as of 2022/07/19, 03:12 UTC\n(source: https://curl.se/ca/cacert.pem)","ref":"changelog.html#changed-14"},{"type":"extras","title":"Removed - Changelog","doc":"- [certificate authority] hellenic academic and research institutions rootca 2011","ref":"changelog.html#removed-8"},{"type":"extras","title":"Fixed - Changelog","doc":"- fragile automated CHANGELOG updates\n- flaky test case\n\n## [1.14.0] - 2022-04-27","ref":"changelog.html#fixed-8"},{"type":"extras","title":"Added - Changelog","doc":"- [certificate authority] d-trust ev root ca 1 2020\n- [certificate authority] d-trust br root ca 1 2020\n- [certificate authority] Telia Root CA v2","ref":"changelog.html#added-12"},{"type":"extras","title":"Changed - Changelog","doc":"- module with bundled CAs to latest as of 2022/04/26, 03:12 UTC\n(source: https://curl.se/ca/cacert.pem)\n\n## [1.13.0] - 2022-03-18","ref":"changelog.html#changed-15"},{"type":"extras","title":"Changed - Changelog","doc":"- module with bundled CAs to latest as of 2022/03/18, 12:30 UTC\n(source: https://curl.se/ca/cacert.pem)","ref":"changelog.html#changed-16"},{"type":"extras","title":"Removed - Changelog","doc":"- [certificate authority] ec-acc\n\n## [1.12.0] - 2022-02-02","ref":"changelog.html#removed-9"},{"type":"extras","title":"Added - Changelog","doc":"- [certificate authority] vtrus ecc root ca\n- [certificate authority] isrg root x2\n- [certificate authority] vtrus root ca\n- [certificate authority] HiPKI Root CA - G1\n- [certificate authority] Autoridad de Certificacion Firmaprofesional CIF A62634068","ref":"changelog.html#added-13"},{"type":"extras","title":"Changed - Changelog","doc":"- module with bundled CAs to latest as of 2022/02/01, 04:12 UTC\n(source: https://curl.se/ca/cacert.pem)\n- [certificate authority] gts root r4\n- [certificate authority] gts root r3\n- [certificate authority] gts root r1\n- [certificate authority] gts root r2\n- [certificate authority] GlobalSign ECC Root CA - R4","ref":"changelog.html#changed-17"},{"type":"extras","title":"Removed - Changelog","doc":"- [certificate authority] GlobalSign Root CA - R2\n- [certificate authority] cybertrust global root\n\n## [1.11.0] - 2021-10-28","ref":"changelog.html#removed-10"},{"type":"extras","title":"Added - Changelog","doc":"- [certificate authority] HARICA TLS ECC Root CA 2021\n- [certificate authority] HARICA TLS RSA Root CA 2021\n- [certificate authority] TunTrust Root CA","ref":"changelog.html#added-14"},{"type":"extras","title":"Changed - Changelog","doc":"- module with bundled CAs to latest as of 2021/10/26, 03:12 UTC\n(source: https://curl.se/ca/cacert.pem)\n\n## [1.10.0] - 2021-10-01","ref":"changelog.html#changed-18"},{"type":"extras","title":"Changed - Changelog","doc":"- module with bundled CAs to latest as of 2021/09/30, 21:42 UTC\n(source: https://curl.se/ca/cacert.pem)","ref":"changelog.html#changed-19"},{"type":"extras","title":"Removed - Changelog","doc":"- [certificate authority] dst root ca x3\n\n## [1.9.0] - 2021-09-03","ref":"changelog.html#removed-11"},{"type":"extras","title":"Added - Changelog","doc":"- test coverage of certificates yet-to-be valid\n- test coverage of misordered certificate chains","ref":"changelog.html#added-15"},{"type":"extras","title":"Changed - Changelog","doc":"- **partial chain validation to prepare for\n[DST Root CA X3 expiration](https://blog.voltone.net/post/30)**\n- documentation from edoc to ExDoc","ref":"changelog.html#changed-20"},{"type":"extras","title":"Removed - Changelog","doc":"- dependency on badssl.com for important test cases\n\n## [1.8.0] - 2021-08-31","ref":"changelog.html#removed-12"},{"type":"extras","title":"Added - Changelog","doc":"- automated PR-based update of bundled CAs through GHA","ref":"changelog.html#added-16"},{"type":"extras","title":"Changed - Changelog","doc":"- app description to tentatively improve it\n\n## [1.7.0] - 2021-07-08","ref":"changelog.html#changed-21"},{"type":"extras","title":"Added - Changelog","doc":"- [certificate authority] certum ec-384 ca\n- [certificate authority] globaltrust 2020\n- [certificate authority] certum trusted root ca\n- [certificate authority] anf secure server root ca","ref":"changelog.html#added-17"},{"type":"extras","title":"Changed - Changelog","doc":"- module with bundled CAs to latest as of 2021/07/05, 21:35 UTC\n(source: https://curl.se/ca/cacert.pem)","ref":"changelog.html#changed-22"},{"type":"extras","title":"Removed - Changelog","doc":"- [certificate authority] sonera class2 ca\n- [certificate authority] trustis fps root ca\n- [certificate authority] quovadis root certification authority\n\n## [1.6.0] - 2021-05-30","ref":"changelog.html#removed-13"},{"type":"extras","title":"Changed - Changelog","doc":"- module with bundled CAs to latest as of 2021/05/25, 03:12 UTC\n(source: https://curl.se/ca/cacert.pem)","ref":"changelog.html#changed-23"},{"type":"extras","title":"Removed - Changelog","doc":"- [certificate authority] global chambersign root - 2008\n- [certificate authority] chambers of commerce root - 2008\n\n## [1.5.0] - 2021-05-13","ref":"changelog.html#removed-14"},{"type":"extras","title":"Added - Changelog","doc":"- OTP 24 to CI targets","ref":"changelog.html#added-18"},{"type":"extras","title":"Removed - Changelog","doc":"- compatibility with OTP 21\n\n## [1.4.0] - 2021-04-16","ref":"changelog.html#removed-15"},{"type":"extras","title":"Added - Changelog","doc":"- [certificate authority] globalsign root e46\n- [certificate authority] AC RAIZ FNMT-RCM SERVIDORES SEGUROS\n- [certificate authority] globalsign root r46","ref":"changelog.html#added-19"},{"type":"extras","title":"Changed - Changelog","doc":"- module with bundled CAs to latest as of 2021/04/13, 03:12 UTC\n(source: https://curl.se/ca/cacert.pem)","ref":"changelog.html#changed-24"},{"type":"extras","title":"Removed - Changelog","doc":"- [certificate authority] geotrust primary certification authority - g2\n- [certificate authority] verisign universal root certification authority\n- [certificate authority] Staat der Nederlanden Root CA - G3\n\n## [1.3.0] - 2021-04-02","ref":"changelog.html#removed-16"},{"type":"extras","title":"Added - Changelog","doc":"- `tls_certificate_check:trusted_authorities/0` to API","ref":"changelog.html#added-20"},{"type":"extras","title":"Changed - Changelog","doc":"- list of authoritative certificates, from hardcoded to one that's generated on application boot\n  and stored on `persistent_term`\n- set of trusted public keys, from hardcoded to one that's generated on application boot\n  and stored on `persistent_term`","ref":"changelog.html#changed-25"},{"type":"extras","title":"Removed - Changelog","doc":"- compatibility with OTP 19\n- compatibility with OTP 20\n- compatibility with OTP 21.0 and 21.1\n- priv/cacerts.pem","ref":"changelog.html#removed-17"},{"type":"extras","title":"Fixed - Changelog","doc":"- unwarranted and risky hardcoding of record values\n\n## [1.2.0] - 2021-03-12","ref":"changelog.html#fixed-9"},{"type":"extras","title":"Added - Changelog","doc":"- elements for easily updating bundled CAs\n- [certificate authority] NAVER Global Root Certification Authority","ref":"changelog.html#added-21"},{"type":"extras","title":"Changed - Changelog","doc":"- module with bundled CAs to latest as of 2021/01/19, 04:12 UTC\n(source: https://curl.se/ca/cacert.pem)","ref":"changelog.html#changed-26"},{"type":"extras","title":"Removed - Changelog","doc":"- [dependency] `certifi`\n- [dependency] `parse_trans`\n- [certificate authority] thawte primary root ca - g2\n- [certificate authority] geotrust global ca\n- [certificate authority] geotrust primary certification authority\n- [certificate authority] verisign class 3 public primary certification authority - g4\n- [certificate authority] geotrust primary certification authority - g3\n- [certificate authority] thawte primary root ca\n- [certificate authority] thawte primary root ca - g3\n- [certificate authority] verisign class 3 public primary certification authority - g5\n- [certificate authority] geotrust universal ca\n- [certificate authority] geotrust universal ca 2","ref":"changelog.html#removed-18"},{"type":"extras","title":"Fixed - Changelog","doc":"- misuse of `tls_certificate_` namespace (all modules start with `tls_certificate_check` now)\n\n## [1.1.1] - 2020-12-08","ref":"changelog.html#fixed-10"},{"type":"extras","title":"Fixed - Changelog","doc":"- compilation errors on OTP 20.1+ when on top of macOS Big Sur\n\n## [1.1.0] - 2020-12-05","ref":"changelog.html#fixed-11"},{"type":"extras","title":"Changed - Changelog","doc":"- CA bundles, based on the latest mkcert.org full CA list as of Nov 13, 2020\n\n## [1.0.2] - 2020-10-16","ref":"changelog.html#changed-27"},{"type":"extras","title":"Fixed - Changelog","doc":"- misdetection of Mix as being rebar 2 and the erronous compilation warning that followed it\n\n## [1.0.1] - 2020-05-21","ref":"changelog.html#fixed-12"},{"type":"extras","title":"Fixed - Changelog","doc":"- missing links to source code in application metadata\n\n## [1.0.0] - 2020-05-21","ref":"changelog.html#fixed-13"},{"type":"extras","title":"Added - Changelog","doc":"- `:options` function to API, for easily securing connections","ref":"changelog.html#added-22"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2020-2024 Guilherme Andrade\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"proglang":"erlang","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.1"}}